require_relative '../../../spec_helper'
require 'uri'

describe "URI::LDAP#filter" do
  it "needs to be reviewed for spec completeness"
end

describe "URI::LDAP#filter=" do
  it "needs to be reviewed for spec completeness"
end
